@@ -47,7 +47,8 @@ class SendGrid(object):
             "subuser": {  # create new subuser
                 "add": "/apiv2/customer.add.json",
                 "list": "/apiv2/customer.profile.json",
-                "del": "/apiv2/customer.delete.json"},
+                "del": "/apiv2/customer.delete.json",
+                "edit": "/apiv2/customer.profile.json"},
             "sendip": {  # create new subuser
                 "add": "/apiv2/customer.sendip.json",
                 "get": "/apiv2/customer.ip.json"},
@@ -130,6 +131,11 @@ class SendGrid(object):
             return new
         return existing
 
+    def edit_newsletter(self, **fields):
+        '''fields must be name, newname, subject, text, html'''
+        identity = self.list_identity()['response'][0]['identity']
+        return self.call('newsletter', 'edit', dict(identity=identity, **fields))
+
     def list_identity(self, name=None):
         return self.call('identity', 'list', {"name": name} if name else {})
 
@@ -149,6 +155,9 @@ class SendGrid(object):
     def del_list(self, name):
         return self.call('lists', 'del', dict(list=name))
 
+    def edit_list(self, list, newlist):
+        return self.call('lists', 'edit', dict(list=list, newlist=newlist))
+
     def add_email_to(self, **fields):
         return self.call('email', 'add', dict(**fields))
 
@@ -190,7 +199,7 @@ class SendGrid(object):
 
     def add_schedule(self, newsletter_name, at=None, after=None):
         if at:
-            d = dict(name=newsletter_name, at=at.isoformat())
+            d = dict(name=newsletter_name, at=at.isoformat() + "+00:00")
         elif after:
             d = dict(name=newsletter_name, after=after)
         else:
@@ -212,6 +221,11 @@ class SendGrid(object):
     def del_subuser(self, user):
         return self.call('subuser', 'del', dict(user=user))
 
+    def edit_subuser(self, user, **fields):
+        '''fields can be first_name, last_name, address, city, state, country, zip, phone,
+        website, company'''
+        return self.call('subuser', 'edit', dict(task="set", user=user, **fields))
+
     def add_sendip(self, **fields):
         '''Fields can be task, user, set, ip'''
         return self.call('sendip', 'add', dict(task="append", **fields))
